==> BuildStream-1.91.2.dev0.tar.gz: BuildStream-1.91.2.dev0/tests/testutils/__init__.py <==
#
#  Copyright (C) 2018 Codethink Limited
#  Copyright (C) 2018 Bloomberg Finance LP
#
#  This program is free software; you can redistribute it and/or
#  modify it under the terms of the GNU Lesser General Public
#  License as published by the Free Software Foundation; either
#  version 2 of the License, or (at your option) any later version.
#
#  This library is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
#  Lesser General Public License for more details.
#
#  You should have received a copy of the GNU Lesser General Public
#  License along with this library. If not, see <http://www.gnu.org/licenses/>.
#
#  Authors: Tristan Van Berkom <tristan.vanberkom@codethink.co.uk>
#           Tristan Maat <tristan.maat@codethink.co.uk>
#           Sam Thursfield <sam.thursfield@codethink.co.uk>
#           James Ennis <james.ennis@codethink.co.uk>
#           Valentin David <valentin.david@codethink.co.uk>
#           William Salmon <will.salmon@codethink.co.uk>
#

from .artifactshare import create_artifact_share, create_split_share, assert_shared, assert_not_shared
from .context import dummy_context
from .element_generators import create_element_size, update_element_size
from .junction import generate_junction
from .runner_integration import wait_for_cache_granularity
from .python_repo import setup_pypi_repo
from .platform import override_platform_uname

==> BuildStream-1.93.6.dev0.tar.gz: BuildStream-1.93.6.dev0/tests/testutils/__init__.py <==
#
#  Copyright (C) 2018 Codethink Limited
#  Copyright (C) 2018 Bloomberg Finance LP
#
#  This program is free software; you can redistribute it and/or
#  modify it under the terms of the GNU Lesser General Public
#  License as published by the Free Software Foundation; either
#  version 2 of the License, or (at your option) any later version.
#
#  This library is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
#  Lesser General Public License for more details.
#
#  You should have received a copy of the GNU Lesser General Public
#  License along with this library. If not, see <http://www.gnu.org/licenses/>.
#
#  Authors: Tristan Van Berkom <tristan.vanberkom@codethink.co.uk>
#           Tristan Maat <tristan.maat@codethink.co.uk>
#           Sam Thursfield <sam.thursfield@codethink.co.uk>
#           James Ennis <james.ennis@codethink.co.uk>
#           Valentin David <valentin.david@codethink.co.uk>
#           William Salmon <will.salmon@codethink.co.uk>
#

from .artifactshare import create_artifact_share, create_split_share, assert_shared, assert_not_shared, ArtifactShare
from .context import dummy_context
from .element_generators import create_element_size, update_element_size
from .junction import generate_junction
from .runner_integration import wait_for_cache_granularity
from .python_repo import setup_pypi_repo
from .platform import override_platform_uname
